==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fIflt.h <==
// class soot.coffi.Instruction_Iflt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 9fed8b9eb3045e56 soot_coffi_Instruction__5fIflt
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 6bcdce6545109d8e soot_coffi_Instruction__5fintbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintbranch

#include "soot/coffi/Instruction__5fintbranch.h"

#ifndef _JC_soot_coffi_Instruction__5fIflt_H_
#define _JC_soot_coffi_Instruction__5fIflt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIflt$sub_refs	_jc_soot_coffi_Instruction__5fIflt$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIflt$sub_nonrefs	_jc_soot_coffi_Instruction__5fIflt$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIflt$refs	_jc_soot_coffi_Instruction__5fIflt$refs;
typedef struct _jc_soot_coffi_Instruction__5fIflt$nonrefs	_jc_soot_coffi_Instruction__5fIflt$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIflt$object	_jc_soot_coffi_Instruction__5fIflt$object;

typedef const struct _jc_soot_coffi_Instruction__5fIflt$vmethods	_jc_soot_coffi_Instruction__5fIflt$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIflt$vtable	_jc_soot_coffi_Instruction__5fIflt$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIflt$vtype	_jc_soot_coffi_Instruction__5fIflt$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIflt$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIflt$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIflt$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIflt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5fintbranch$vmethods	soot_coffi_Instruction__5fintbranch;
	_jc_soot_coffi_Instruction__5fIflt$vmethods	soot_coffi_Instruction__5fIflt;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIflt$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIflt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIflt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIflt$refs {
    _jc_soot_coffi_Instruction__5fIflt$sub_refs	soot_coffi_Instruction__5fIflt;
    _jc_soot_coffi_Instruction__5fintbranch$sub_refs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIflt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIflt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5fintbranch$sub_nonrefs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fIflt$sub_nonrefs	soot_coffi_Instruction__5fIflt;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIflt$object {
	_jc_soot_coffi_Instruction__5fIflt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIflt$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIflt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIflt$vtype _jc_soot_coffi_Instruction__5fIflt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIflt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIflt$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIflt_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fIflt.h <==
// class soot.coffi.Instruction_Iflt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 9fed8b9eb3045e56 soot_coffi_Instruction__5fIflt
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 6bcdce6545109d8e soot_coffi_Instruction__5fintbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintbranch

#include "soot/coffi/Instruction__5fintbranch.h"

#ifndef _JC_soot_coffi_Instruction__5fIflt_H_
#define _JC_soot_coffi_Instruction__5fIflt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIflt$sub_refs	_jc_soot_coffi_Instruction__5fIflt$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIflt$sub_nonrefs	_jc_soot_coffi_Instruction__5fIflt$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIflt$refs	_jc_soot_coffi_Instruction__5fIflt$refs;
typedef struct _jc_soot_coffi_Instruction__5fIflt$nonrefs	_jc_soot_coffi_Instruction__5fIflt$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIflt$object	_jc_soot_coffi_Instruction__5fIflt$object;

typedef const struct _jc_soot_coffi_Instruction__5fIflt$vmethods	_jc_soot_coffi_Instruction__5fIflt$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIflt$vtable	_jc_soot_coffi_Instruction__5fIflt$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIflt$vtype	_jc_soot_coffi_Instruction__5fIflt$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIflt$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIflt$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIflt$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIflt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5fintbranch$vmethods	soot_coffi_Instruction__5fintbranch;
	_jc_soot_coffi_Instruction__5fIflt$vmethods	soot_coffi_Instruction__5fIflt;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIflt$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIflt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIflt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIflt$refs {
    _jc_soot_coffi_Instruction__5fIflt$sub_refs	soot_coffi_Instruction__5fIflt;
    _jc_soot_coffi_Instruction__5fintbranch$sub_refs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIflt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIflt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5fintbranch$sub_nonrefs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fIflt$sub_nonrefs	soot_coffi_Instruction__5fIflt;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIflt$object {
	_jc_soot_coffi_Instruction__5fIflt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIflt$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIflt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIflt$vtype _jc_soot_coffi_Instruction__5fIflt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIflt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIflt$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIflt_H_ */
